// ----------------------------------------------------------------------------
// Copyright (C) 2014
//              David Freese, W1HKJ
//
// This file is part of flmsg
//
// flrig is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.
//
// flrig is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------

#ifndef FLMSG_CONFIG_H_
#define FLMSG_CONFIG_H_

#define DATAFILE_EXT  ".f2s"
#define DATATEMP_EXT  ".f2t"

#define F203_EXT      ".203"
#define T203_EXT      ".203T"

#define F205_EXT      ".205"
#define T205_EXT      ".205T"

#define F205A_EXT     ".25A"
#define T205A_EXT     ".25T"

#define F206_EXT      ".206"
#define T206_EXT      ".206T"

#define F213_EXT      ".213"
#define T213_EXT      ".213T"

#define F214_EXT      ".214"
#define T214_EXT      ".214T"

#define F216_EXT      ".216"
#define T216_EXT      ".216T"

#define F309_EXT      ".309"
#define T309_EXT      ".309T"

#define FNET_EXT      ".Fnet"
#define TNET_EXT      ".Tnet"

#define HF203_EXT     ".H203"
#define HT203_EXT     ".H203T"

#define HF206_EXT     ".H206"
#define HT206_EXT     ".H206T"

#define HF213_EXT     ".H213"
#define HT213_EXT     ".H213T"

#define HF214_EXT     ".H214"
#define HT214_EXT     ".H214T"

#define RGFILE_EXT    ".m2s"
#define RGTEMP_EXT    ".m2t"

#define IARU_FILE_EXT ".i2s"
#define IARU_TEMP_EXT ".i2t"

#define PTFILE_EXT    ".p2s"
#define PTTEMP_EXT    ".p2t"

#define BLANKFILE_EXT ".b2s"
#define BLANKTEMP_EXT ".b2t"

#define CSVFILE_EXT  ".c2s"
#define CSVTEMP_EXT  ".c2t"

#define CUSTOMFILE_EXT ".k2s"
#define CUSTOMTEMP_EXT ".k2t"

#define FMARSDAILY_EXT ".mds"
#define TMARSDAILY_EXT ".mdt"

#define FMARSINEEI_EXT ".mis"
#define TMARSINEEI_EXT ".mit"

#define FMARSNET_EXT ".mns"
#define TMARSNET_EXT ".mnt"

#define FMARSARMY_EXT ".nas"
#define TMARSARMY_EXT ".nat"

#define FMARSMSG_EXT ".msg"
#define TMARSMSG_EXT ".msg"

#define FREDXSNW_EXT ".sws"
#define TREDXSNW_EXT ".swt"

#define FREDX5739_EXT ".39s"
#define TREDX5739_EXT ".39t"

#define FREDX5739A_EXT ".3as"
#define TREDX5739A_EXT ".3at"

#define FREDX5739B_EXT ".3bs"
#define TREDX5739B_EXT ".3bt"

#define FWXHC_EXT      ".w2s"
#define TWXHC_EXT      ".w2t"

#define FSWX_EXT       ".s2s"
#define TSWX_EXT       ".s2t"

#define FSTRM_EXT      ".fstm2s"
#define TSTRM_EXT      ".tstm2s"

#define CAP105_FILE_EXT  ".c105F"
#define CAP105_TEMP_EXT  ".c105T"

#define CAP110_FILE_EXT      ".c110F"
#define CAP110_TEMP_EXT      ".c110T"

#define TRANSFER_EXT   ".xfr"

#define WRAP_EXT      ".wrap"

#endif

